<?php
/* spl_aggregate_writeXML.php --- Charlie Roberts 1.30.2008
** 
** This script aggregates data from George Legrady's "Making Visible the Invisible"
** project (http://www.mat.ucsb.edu/~g.legrady/glWeb/Projects/spl/spl.html). It creates
** a heavily compressed XML file that providing user defined variables of the SPL data
** over a user defined time-span.
*/

ini_set("memory_limit", "256M");        // limit the memory
ini_set("max_execution_time", "600");   // limit the max execution time... increase for more than 1 month.

echo("Start...\n");

// THESE VARIABLES NEED TO BE CHANGED FOR EACH RUN

$year = 2007; 
$month = 12;
$dayEnd = 30;       // last day of data you want

$inOut = 'out';     // checkins(in)? or checkouts(out)?
$filename = 'deweyCKO_30_nockitime';

$values = array('v1'=>'deweyClass', 'v2'=>'ckitime'); // each value gets 1 added to key ie, 'v1', 'v2', 'v3'... etc

// END VARIABLES TO BE CHANGED

$transactionCount = 0;
$DOM  = domxml_new_doc('1.0');
$root = $DOM->append_child($DOM->create_element('root'));

$urlToOpen_start = "/var/www/spl/data/";//.$year."/".$month."/".$day."/";

$fh = fopen("./aggregatedfiles/".$filename.".xml", 'w');
$xmlString = '<?xml version="1.0" encoding="UTF-8"?><root>';
$error = fputs($fh, $xmlString);

for($j = $month; $j <= $month; $j++) {    // change second param to look at multiple months
  $month = $j;
  if($month < 10) $month = '0'.$month;    // add a 0 if month is less than 10... ie 8 becomes 08, 3 becomes 03... for filename purposes
  
  for($k = 1; $k <= $dayEnd; $k++) {      // for each day...
    echo("\nProcessing day ".$k." --- ");
    $xmlString = "<d n=\"$k\">";
  
    $day = $k;
    if($day < 10) $day = '0'.$day;
  
    for($l = 0; $l < 24; $l++) {          // for each hour
      echo($l." :: ");
      $hour = $l;
      $xmlString .= "<h n=\"$l\">";
      
      if($hour < 10) $hour = '0'.$hour;
      
      $urlToOpen = $urlToOpen_start . $year.'/'.$month.'/'.$day.'/';            // filename to open start
      $urlToOpen .= $inOut."-".$year."-".$month."-".$day."-".$hour.".xml";      // filename to open end
      $doc = domxml_open_file($urlToOpen);                                      // open file pointed to by filname
      if(!$doc) {
	      $xmlString .= "</h>";                                                   // if you can't find file for this hour, close the hour node and move on to next hour
      	continue;
      }
      
      $transactions = $doc->get_elements_by_tagname( "transaction" );
      
      foreach( $transactions as $transaction ){
        $dontskip = true;
        $tString = '<t>';
        
        foreach ($values as $key => $value) {
          if(!$dontskip) continue;
          $nodes = $transaction->get_elements_by_tagname( $value );
          $node = $nodes[0];
          $nodeString = $node->get_content();
          if ($nodeString == '') {
            $dontskip = false;
            continue;                 // move to next transaction if this one does not have the variable we're looking for
          }
          if($value == "deweyClass") {
    	      $nodeStringExplode = explode(".", $nodeString);   // divide number into left and right of decimal point
    	      $nodeString = $nodeStringExplode[0];              // get just the integer
    	    }
          $tString .= "<v>$nodeString</v>";
        }

        if($dontskip) { 
          $tString .= '</t>';
          $xmlString .= $tString;
      	  $transactionCount++;
        }
      }
      $xmlString .= '</h>';
      $doc->free();
    } // --------------- end transaction -----------------
    
    $xmlString .= '</d>';
    $error = fputs($fh, $xmlString);
    
  } // ----------------- end day -------------------------
}
$xmlString = '</root>';
$error = fputs($fh, $xmlString);

fclose($fh);
echo("\n\n -------- FILE WRITTEN ---------");
echo("There were $transactionCount transactions\n");
exit();

?>
